# Instructions to run

Copy content from the keras-to-hls directory:

```cp -r ../../keras-to-hls/example-keras-model-files ./```

Then run the conversion script:

```python ../../keras-to-hls/keras-to-hls.py -c keras-config.yml```
